// Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.VSPowerToys.BestPracticesAnalyzer.Common;
using Microsoft.VSPowerToys.BestPracticesAnalyzer.UserInterface;

namespace AspDotNetAnalyzer
{
    public class AspDotNetAnalyzer : Analyzer
    {
        #region Global Members

        /// <summary>
        ///  Using the base ScanOptions screen from UserInterface.
        /// </summary>
        protected ScanOptions scanOptions = null;

        #endregion

        public AspDotNetAnalyzer(string[] args)
            : base(args)
        {
            mconfigurationFileName = "AspDotNetAnalyzer.config.xml";

            //Set the required Tool strings
            Tool_ShortName = "Microsoft ASP.NET BPA";
            Tool_LongNameStart = "Microsoft ASP.NET";
            Tool_LongNameEnd = "Best Practices Analyzer";
            Label_WDesc = "This is the Best Practices Analyzer for Microsoft ASP.NET";
            Button_StartScan = "Start a new Best Practices scan";
        }

        /// <summary>
        /// This will fill in the run time options for a scan.
        /// </summary>
        /// <param name="scanInfo"></param>
        /// <param name="argsIn"></param>
        protected override void GetBPAScanInfo(BPAScanInfo scanInfo, string[] argsIn)
        {
            scanInfo.Options.Label = scanOptions.Label;
            scanInfo.Options.DC = scanOptions.ADServer;

            scanInfo.Options.Restrictions.DisableAll();
            foreach (string option in scanOptions.RestrictionOptions)
                scanInfo.Options.Restrictions.Enable(option);

            scanInfo.Options.Substitutions.Clear();
            for (int s = 0; s < scanOptions.Substitutions.Count; s++)
                scanInfo.Options.Substitutions.Add(scanOptions.Substitutions.GetKey(s), scanOptions.Substitutions.GetByIndex(s));

            scanInfo.Options.CredentialsList.Clear();
            foreach (Credentials creds in scanOptions.CredentialsList)
                scanInfo.Options.CredentialsList.Add(creds.ContextName, creds);
        }

        /// <summary>
        /// This does any custom initialization needed.
        /// </summary>
        public override void InitializeAnalyzerCustomizations()
        {
            mcustomizations = new BPACustomizations("BPA", new BPACustomizations.GetBPAScanInfoCallback(GetBPAScanInfo));
            mcustomizations.ProcessConfiguration = new BPACustomizations.ProcessConfigurationCallback(ProcessConfiguration);
            mcustomizations.Button_AppWebSite = BPALoc.Button_Exchange(Tool_ShortName);
            mcustomizations.AppWebSite = null;
            mcustomizations.CommandLineApplicationName = "bpacmd.exe";
            mcustomizations.ShortName = Tool_ShortName;
            mcustomizations.LongNameStart = Tool_LongNameStart;
            mcustomizations.LongNameEnd = Tool_LongNameEnd;
            mcustomizations.RegistrySettings = new BPARegistrySettings();
            mcustomizations.AllowAutoDownloads = false;
            mcustomizations.Description = Label_WDesc;
            scanOptions = new ScanOptions(this);
            mcustomizations.CustomScreens.Add(scanOptions);
            mcustomizations.CheckAssemblySignature = false;
            mcustomizations.CheckConfigurationSignature = false;
        }


        /// <summary>
        /// This will do any additional configuration initialization needed.
        /// </summary>
        /// <param name="doc"></param>
        protected override void ProcessConfiguration(Document doc)
        {
            if (scanOptions != null && mainGUI != null)
                scanOptions.Initialize(mainGUI);
        }

        /// <summary>
        /// This will format an analyzer description to be displayed in the UI.
        /// </summary>
        public override string ToString()
        {
            return LongNameStart + " " + LongNameEnd;
        }
    }
}
